
extends Node


var mainGameScene = preload("res://scenes/main_map.scn")

const MENU_MAIN = 1
const MENU_OPTIONS = 2

var initialFocus = false
var currentMenu = 1


func _ready():
	get_tree().set_pause(false)
	set_process_input(true)
	
	initialFocus = false
	currentMenu = MENU_MAIN
	
	if OS.get_window_size().x == 960:
		get_node("Options/VBoxContainer/SizeButton").set_pressed(true)
		get_node("Options/VBoxContainer/SizeButton/Label").set_text("SIZE: 2X")
	
	if AudioServer.get_stream_global_volume_scale() < 1:
		get_node("Options/VBoxContainer/MusicButton").set_pressed(true)
		get_node("Options/VBoxContainer/MusicButton/Label").set_text("MUSIC:OFF")
	
	if AudioServer.get_fx_global_volume_scale() < 1:
		get_node("Options/VBoxContainer/SoundButton").set_pressed(true)
		get_node("Options/VBoxContainer/SoundButton/Label").set_text("SOUND:OFF")


func _input(event):
	if not initialFocus:
		if event.is_action_pressed("ui_down") or event.is_action_pressed("ui_focus_next"):
			get_tree().set_input_as_handled()
			if currentMenu == MENU_MAIN:
				get_node("Menu/VBoxContainer/QuitButton").grab_focus()
				
			elif currentMenu == MENU_OPTIONS:
				get_node("Options/VBoxContainer/BackButton").grab_focus()
			
			initialFocus = true
			
		elif event.is_action_pressed("ui_up") or event.is_action_pressed("ui_focus_prev"):
			get_tree().set_input_as_handled()
			if currentMenu == MENU_MAIN:
				get_node("Menu/VBoxContainer/StartButton").grab_focus()
				
			elif currentMenu == MENU_OPTIONS:
				get_node("Options/VBoxContainer/SizeButton").grab_focus()
			
			initialFocus = true
	
	if event.is_action_pressed("ui_cancel"):
		if currentMenu == MENU_MAIN:
			if get_node("Menu/VBoxContainer/QuitButton").has_focus():
				_on_QuitButton_pressed()
			get_node("Menu/VBoxContainer/QuitButton").grab_focus()
			initialFocus = true
			
		elif currentMenu == MENU_OPTIONS:
			if get_node("Options/VBoxContainer/BackButton").has_focus():
				_on_BackButton_pressed()
			get_node("Options/VBoxContainer/BackButton").grab_focus()
			initialFocus = true


func _on_StartButton_pressed():
	get_node("SamplePlayer").play("button_press")
	get_tree().change_scene_to(mainGameScene)


func _on_OptionsButton_pressed():
	get_node("SamplePlayer").play("button_press")
	get_node("Menu").get_focus_owner().release_focus()
	initialFocus = false
	
	currentMenu = MENU_OPTIONS
	
	get_node("AnimationPlayer").play("switch")


func _on_QuitButton_pressed():
	get_node("SamplePlayer").play("button_press")
	get_tree().quit()


func _on_SizeButton_toggled( pressed ):
	get_node("SamplePlayer").play("button_press")
	if pressed:
		get_node("Options/VBoxContainer/SizeButton/Label").set_text("SIZE: 2X")
		OS.set_window_size(Vector2(960, 960))
	else:
		get_node("Options/VBoxContainer/SizeButton/Label").set_text("SIZE: 1X")
		OS.set_window_size(Vector2(480, 480))


func _on_MusicButton_toggled( pressed ):
	get_node("SamplePlayer").play("button_press")
	if pressed:
		get_node("Options/VBoxContainer/MusicButton/Label").set_text("MUSIC:OFF")
		AudioServer.set_stream_global_volume_scale(0)
	else:
		get_node("Options/VBoxContainer/MusicButton/Label").set_text("MUSIC: ON")
		AudioServer.set_stream_global_volume_scale(1)


func _on_SoundButton_toggled( pressed ):
	get_node("SamplePlayer").play("button_press")
	if pressed:
		get_node("Options/VBoxContainer/SoundButton/Label").set_text("SOUND:OFF")
		AudioServer.set_fx_global_volume_scale(0)
	else:
		get_node("Options/VBoxContainer/SoundButton/Label").set_text("SOUND: ON")
		AudioServer.set_fx_global_volume_scale(1)


func _on_BackButton_pressed():
	get_node("SamplePlayer").play("button_press")
	get_node("Options").get_focus_owner().release_focus()
	initialFocus = false
	
	currentMenu = MENU_MAIN
	
	get_node("AnimationPlayer").play_backwards("switch")


