
extends Node2D


var mainMenuScene = preload("res://scenes/main_menu.scn")

const STATE_PLAYING = 1
const STATE_WIN = 2
const STATE_LOSE = 4
const STATE_WAIT = 8

#rooms[level][type][height]
var rooms = []
var maxLevel = 0

var state = STATE_WAIT
var level = 0

var timeScore = 0


func clear_map():
	for i in range(15):
		var room = get_node("Rooms").get_child(i)
		if room:
			room.queue_free()


func build_map():
	var lastRoom = -1
	var i = 0
	while i < 15:
		randomize()
		var roomHeight = 1
		
		if i == 0:
			var room = rooms[0][0][0][randi() % rooms[0][0][0].size()].instance()
			room.set_name("Room 0")
			get_node("Rooms").add_child(room)
			get_node("Player").set_pos(room.get_node("Player Spawn").get_pos())
			get_node("Player").spawn()
			
		elif i < 14:
			var height = 0
			if rooms[0][1].size() > 1 and i < 13:
				if randi() % 4 == 0:
					height = 1
					roomHeight = 2
			
			var randomRoom = randi() % rooms[0][1][height].size()
			while randomRoom == lastRoom:
				randomRoom = randi() % rooms[0][1][height].size()
			lastRoom = randomRoom
			
			var room = rooms[0][1][height][randomRoom].instance()
			room.set_name("Room " + str(i))
			room.set_pos(Vector2(0, (-480 * i) + (-480 * height)))
			get_node("Rooms").add_child(room)
			
		else:
			var room = rooms[0][2][0][randi() % rooms[0][2][0].size()].instance()
			room.set_name("Room " + str(i))
			room.set_pos(Vector2(0, -480 * room.get_height() * i))
			get_node("Rooms").add_child(room)
		
		i += roomHeight


func next_level():
	state = STATE_WAIT
	get_node("Fade").level_fade_out(false)


func next_level_build():
	level += 1
	timeScore = 0
	
	clear_map()
	build_map()
	
	get_node("LoseMenu").hide()
	get_node("WinMenu").hide()
	get_node("Fade").level_fade_in()


func restart():
	state = STATE_WAIT
	get_node("Fade").level_fade_out(true)


func restart_build():
	level = 0
	timeScore = 0
	
	get_node("Player").restart()
	
	clear_map()
	build_map()
	
	get_node("LoseMenu").hide()
	get_node("WinMenu").hide()
	get_node("Fade").level_fade_in()


func level_start():
	get_node("SamplePlayer").play("ready")
	state = STATE_PLAYING
	get_node("Player").start()


func win():
	get_node("Player").win()
	if state != STATE_WIN:
		get_node("WinMenu").show()
		
		var winTime = ""
		var timeMin = int(timeScore / 60.0)
		var timeSec = int(timeScore) % 60
		var timeMsec = floor((int(timeScore * 60.0) % 60) / 0.6)
		
		if timeMin < 10:
			timeMin = "0" + str(timeMin)
		if timeSec < 10:
			timeSec = "0" + str(timeSec)
		if timeMsec < 10:
			timeMsec = "0" + str(timeMsec)
		
		winTime = str(timeMin) + ":" + str(timeSec) + "." + str(timeMsec)
		
		get_node("WinMenu/Menu/Time").set_text("COMPLETED IN:\n" + winTime)
	
	state = STATE_WIN


func goto_menu():
	get_tree().set_pause(false)
	get_tree().change_scene_to(mainMenuScene)


func _ready():
	set_process_input(true)
	set_fixed_process(true)
	
	#Build room list
	var d = Directory.new()
	d.open("res://scenes/rooms")
	d.list_dir_begin()
	var file = d.get_next()
	while file != "":
		if file[0] == "r":
			var roomFile = load("res://scenes/rooms/" + file)
			var ri = roomFile.instance()
			
			rooms.resize(max(ri.level + 1, rooms.size()))
			if rooms[ri.level] == null:
				rooms[ri.level] = []
				maxLevel = max(ri.level, maxLevel)
			
			rooms[ri.level].resize(max(ri.roomType + 1, rooms[ri.level].size()))
			if rooms[ri.level][ri.roomType] == null:
				rooms[ri.level][ri.roomType] = []
			
			rooms[ri.level][ri.roomType].resize(max(ri.height + 1, rooms[ri.level][ri.roomType].size()))
			if rooms[ri.level][ri.roomType][ri.height] == null:
				rooms[ri.level][ri.roomType][ri.height] = []
			
			rooms[ri.level][ri.roomType][ri.height].append(roomFile)
			
		file = d.get_next()
	d.list_dir_end()
	
	build_map()
	get_node("Fade").level_fade_in()


func _input(event):
	if event.is_action_pressed("ui_pause") and (state == STATE_PLAYING or state == STATE_WAIT):
		get_node("SamplePlayer").play("button_press")
		get_node("PauseMenu").show()


func _fixed_process(delta):
	var player = get_node("Player")
	var plyPos = player.get_pos()
	
	if player.dead:
		if state != STATE_LOSE:
			get_node("LoseMenu").show()
		state = STATE_LOSE
	
	if state == STATE_PLAYING:
		timeScore += delta
	
	if plyPos.x < 0:
		plyPos.x = 480
		plyPos.y -= 0
	
	elif plyPos.x > 480:
		plyPos.x = 0
		plyPos.y -= 0
	
	if plyPos != player.get_pos():
		player.set_pos(plyPos)
	
	var weatherNode = get_node("ParallaxForeground/Weather/Snow")
	if plyPos.y < -480 * 11:
		weatherNode.set_emitting(false)
	else:
		weatherNode.set_emitting(true)
	
	var starsNode = get_node("ParallaxBackground/Distant Sky/Stars")
	var a = clamp(1 - ((plyPos.y - (-480 * 15)) / (480 * 3.0)), 0, 0.5)
	starsNode.set_modulate(Color(1, 1, 1, a))


